@@ -1,5 +1,5 @@
 // ButtonTool.cc for Fluxbox
-// Copyright (c) 2003 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2003 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
 // copy of this software and associated documentation files (the "Software"),
@@ -19,7 +19,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: ButtonTool.cc 3932 2005-04-10 18:18:14Z simonb $
+// $Id: ButtonTool.cc 4302 2006-04-15 16:41:11Z simonb $
 
 #include "ButtonTool.hh"
 
@@ -67,7 +67,7 @@ void ButtonTool::renderTheme(unsigned char alpha) {
         btn.setBackgroundColor(theme().texture().color());
     } else {
         m_cache_pm = m_image_ctrl.renderImage(width(), height(),
-                                              theme().texture());
+                                              theme().texture(), orientation());
         btn.setBackgroundPixmap(m_cache_pm);
     }
     if (old_pm)
@@ -79,7 +79,7 @@ void ButtonTool::renderTheme(unsigned char alpha) {
         btn.setPressedColor(static_cast<const ButtonTheme &>(theme()).pressed().color());
     } else {
         m_cache_pressed_pm = m_image_ctrl.renderImage(width(), height(),
-                                                      static_cast<const ButtonTheme &>(theme()).pressed());
+                                                      static_cast<const ButtonTheme &>(theme()).pressed(), orientation());
         btn.setPressedPixmap(m_cache_pressed_pm);
     }
 
