@@ -20,7 +20,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: ClockTool.cc 4227 2006-03-02 07:49:13Z mathias $
+// $Id: ClockTool.cc 4844 2007-04-08 01:59:41Z simonb $
 
 #include "ClockTool.hh"
 
@@ -45,6 +45,7 @@
 #else
   #include <time.h>
 #endif
+#include <sys/time.h>
 #include <string>
 #include <typeinfo>
 
@@ -57,9 +58,9 @@ public:
         if (m_tool.timeFormat().find("%k") != std::string::npos ||
             m_tool.timeFormat().find("%H") != std::string::npos ||
             m_tool.timeFormat().find("%T") != std::string::npos)
-            setLabel( _FBTEXT(Toolbar, Clock24,   "Clock: 24h",   "set Clockmode to 24h") );
+            setLabel( _FB_XTEXT(Toolbar, Clock24,   "Clock: 24h",   "set Clockmode to 24h") );
         else
-            setLabel( _FBTEXT(Toolbar, Clock12,   "Clock: 12h",   "set Clockmode to 12h") );
+            setLabel( _FB_XTEXT(Toolbar, Clock12,   "Clock: 12h",   "set Clockmode to 12h") );
     }
 
     void click(int button, int time) {
@@ -106,9 +107,9 @@ public:
             if (m_tool.timeFormat().find("%k") != std::string::npos ||
                 m_tool.timeFormat().find("%H") != std::string::npos ||
                 m_tool.timeFormat().find("%T") != std::string::npos)
-                setLabel( _FBTEXT(Toolbar, Clock24,   "Clock: 24h",   "set Clockmode to 24h") );
+                setLabel( _FB_XTEXT(Toolbar, Clock24,   "Clock: 24h",   "set Clockmode to 24h") );
             else
-                setLabel( _FBTEXT(Toolbar, Clock12,   "Clock: 12h",   "set Clockmode to 12h") );
+                setLabel( _FB_XTEXT(Toolbar, Clock12,   "Clock: 12h",   "set Clockmode to 12h") );
         
         } // else some other strange format...so we don't do anything
         FbTk::MenuItem::click(button, time);
@@ -142,18 +143,24 @@ ClockTool::ClockTool(const FbTk::FbWindow &parent,
     m_screen(screen),
     m_pixmap(0),
     m_timeformat(screen.resourceManager(), std::string("%k:%M"), 
-                 screen.name() + ".strftimeFormat", screen.altName() + ".StrftimeFormat") {
+                 screen.name() + ".strftimeFormat", screen.altName() + ".StrftimeFormat"),
+    m_stringconvertor(FbTk::StringConvertor::ToFbString) {
     // attach signals
     theme.reconfigSig().attach(this);
 
-    _FB_USES_NLS;	
+    std::string time_locale = setlocale(LC_TIME, NULL);
+    size_t pos = time_locale.find('.');
+    if (pos != std::string::npos)
+        time_locale = time_locale.substr(pos+1);
+    if (!time_locale.empty())
+        m_stringconvertor.setSource(time_locale);
+
+    _FB_USES_NLS;
 
     // setup timer to check the clock every 0.01 second
     // if nothing has changed, it wont update the graphics
-    timeval delay;
-    delay.tv_sec = 0;
-    delay.tv_usec = 100000;
-    m_timer.setTimeout(delay);
+    m_timer.setInterval(1);
+    // m_timer.setTimeout(delay); // don't need to set timeout on interval timer
     FbTk::RefCount<FbTk::Command> update_graphic(new FbTk::SimpleCommand<ClockTool>(*this, 
                                                                                     &ClockTool::updateTime));
     m_timer.setCommand(update_graphic);
@@ -167,7 +174,7 @@ ClockTool::ClockTool(const FbTk::FbWindow &parent,
     item->setCommand(saverc);
     menu.insert(item);
     FbTk::RefCount<FbTk::Command> editformat_cmd(new EditClockFormatCmd());
-    menu.insert(_FBTEXT(Toolbar, ClockEditFormat,   "Edit Clock Format",   "edit Clock Format") , editformat_cmd);
+    menu.insert(_FB_XTEXT(Toolbar, ClockEditFormat,   "Edit Clock Format",   "edit Clock Format") , editformat_cmd);
 
 
     update(0);
@@ -213,11 +220,25 @@ void ClockTool::update(FbTk::Subject *subj) {
     updateTime();
 
     // + 2 to make the entire text fit inside
-    std::string text(m_button.text().size() + 2, '0');
+    // we only replace numbers with zeros because everything else should be 
+    // relatively static. If we replace all text with zeros then widths of
+    // proportional fonts with some strftime formats will be considerably off.
+    std::string text(m_button.text());
 
-    int new_width = m_theme.font().textWidth(text.c_str(), text.size());
-    if (new_width != m_button.width()) {
-        resize(new_width, m_button.height());
+    int textlen = text.size();    
+    for (int i=0; i < textlen; ++i) {
+        if (isdigit(text[i])) // don't bother replacing zeros
+            text[i] = '0';
+    }
+    text.append("00"); // pad
+
+    unsigned int new_width = m_button.width();
+    unsigned int new_height = m_button.height();
+    translateSize(orientation(), new_width, new_height);
+    new_width = m_theme.font().textWidth(text.c_str(), text.size());
+    translateSize(orientation(), new_width, new_height);
+    if (new_width != m_button.width() || new_height != m_button.height()) {
+        resize(new_width, new_height);
         resizeSig().notify();
     }
 
@@ -239,20 +260,33 @@ unsigned int ClockTool::height() const {
 }
 
 void ClockTool::updateTime() {
-
     // update clock
-    time_t the_time = time(0);
+    timeval now;
+    gettimeofday(&now, 0);
+    time_t the_time = now.tv_sec;
 
     if (the_time != -1) {
         char time_string[255];
+        int time_string_len;
         struct tm *time_type = localtime(&the_time);
         if (time_type == 0)
             return;
 
 #ifdef HAVE_STRFTIME
-        if (!strftime(time_string, 255, m_timeformat->c_str(), time_type) || m_button.text() == time_string)
+        time_string_len = strftime(time_string, 255, m_timeformat->c_str(), time_type);
+        if( time_string_len == 0)
             return;
-        m_button.setText(time_string);
+        std::string text = m_stringconvertor.recode(time_string);
+        if (m_button.text() == text)
+            return;
+
+        m_button.setText(text);
+
+        unsigned int new_width = m_theme.font().textWidth(time_string, time_string_len) + 2;
+        if (new_width > m_button.width()) {
+            resize(new_width, m_button.height());
+            resizeSig().notify();
+        }
 #else // dont have strftime so we have to set it to hour:minut
         //        sprintf(time_string, "%d:%d", );
 #endif // HAVE_STRFTIME
@@ -272,7 +306,7 @@ void ClockTool::reRender() {
 
     if (m_theme.texture().usePixmap()) {
         m_pixmap = m_screen.imageControl().renderImage(width(), height(),
-                                                       m_theme.texture());
+                                                       m_theme.texture(), orientation());
         m_button.setBackgroundPixmap(m_pixmap);
     } else {
         m_pixmap = 0;
@@ -291,3 +325,8 @@ void ClockTool::renderTheme(unsigned char alpha) {
     m_button.setBorderColor(m_theme.border().color());
     m_button.clear();
 }
+
+void ClockTool::setOrientation(FbTk::Orientation orient) {
+    m_button.setOrientation(orient);
+    ToolbarItem::setOrientation(orient);
+}
