@@ -20,7 +20,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: CurrentWindowCmd.cc 4206 2006-02-18 20:19:22Z fluxgen $
+// $Id: CurrentWindowCmd.cc 4959 2007-07-02 05:26:32Z markt $
 
 #include "CurrentWindowCmd.hh"
 
@@ -34,9 +34,9 @@
 CurrentWindowCmd::CurrentWindowCmd(Action act):m_action(act) { }
 
 void CurrentWindowCmd::execute() {
-    WinClient *client = FocusControl::focusedWindow();
-    if (client && client->fbwindow())
-        (client->fbwindow()->*m_action)();
+    FluxboxWindow *win = FocusControl::focusedFbWindow();
+    if (win)
+        (win->*m_action)();
 }
 
 
@@ -53,15 +53,15 @@ void SendToWorkspaceCmd::real_execute() {
 }
 
 void SendToNextWorkspaceCmd::real_execute() {
-    const int ws_nr = 
-        ( fbwindow().screen().currentWorkspaceID() + m_workspace_num ) % 
+    const int ws_nr =
+        ( fbwindow().screen().currentWorkspaceID() + m_workspace_num ) %
           fbwindow().screen().numberOfWorkspaces();
     fbwindow().screen().sendToWorkspace(ws_nr, &fbwindow(), false);
 }
 
 void SendToPrevWorkspaceCmd::real_execute() {
     int ws_nr = fbwindow().screen().currentWorkspaceID() - m_workspace_num;
-    if ( ws_nr < 0 ) 
+    if ( ws_nr < 0 )
         ws_nr += fbwindow().screen().numberOfWorkspaces();
     fbwindow().screen().sendToWorkspace(ws_nr, &fbwindow(), false);
 }
@@ -71,34 +71,34 @@ void TakeToWorkspaceCmd::real_execute() {
 }
 
 void TakeToNextWorkspaceCmd::real_execute() {
-    unsigned int workspace_num= 
-        ( fbwindow().screen().currentWorkspaceID() + m_workspace_num ) % 
+    unsigned int workspace_num=
+        ( fbwindow().screen().currentWorkspaceID() + m_workspace_num ) %
           fbwindow().screen().numberOfWorkspaces();
     fbwindow().screen().sendToWorkspace(workspace_num, &fbwindow());
 }
 
 void TakeToPrevWorkspaceCmd::real_execute() {
     int workspace_num= fbwindow().screen().currentWorkspaceID() - m_workspace_num;
-    if ( workspace_num < 0 ) 
+    if ( workspace_num < 0 )
         workspace_num += fbwindow().screen().numberOfWorkspaces();
     fbwindow().screen().sendToWorkspace(workspace_num, &fbwindow());
 }
 
 void GoToTabCmd::real_execute() {
-    if (fbwindow().numClients() <= 1 || m_tab_num > fbwindow().numClients())
-        return;
+    int num = m_tab_num;
+    if (num < 0) num += fbwindow().numClients() + 1;
+    if (num < 1) num = 1;
+    if (num > fbwindow().numClients()) num = fbwindow().numClients();
 
     FluxboxWindow::ClientList::iterator it = fbwindow().clientList().begin();
 
-    int num = m_tab_num;
     while (--num > 0) ++it;
 
-    fbwindow().setCurrentClient(**it, true);
+    (*it)->focus();
 }
 
 void WindowHelperCmd::execute() {
-    WinClient *client = FocusControl::focusedWindow();
-    if (client && client->fbwindow()) // guarantee that fbwindow() exists too
+    if (FocusControl::focusedFbWindow()) // guarantee that fbwindow() exists too
         real_execute();
 }
 
@@ -109,7 +109,7 @@ WinClient &WindowHelperCmd::winclient() {
 
 FluxboxWindow &WindowHelperCmd::fbwindow() {
     // will exist from execute above
-    return *FocusControl::focusedWindow()->fbwindow();
+    return *FocusControl::focusedFbWindow();
 }
 
 MoveCmd::MoveCmd(const int step_size_x, const int step_size_y) :
@@ -125,12 +125,12 @@ ResizeCmd::ResizeCmd(const int step_size_x, const int step_size_y) :
     m_step_size_x(step_size_x), m_step_size_y(step_size_y) { }
 
 void ResizeCmd::real_execute() {
-  
-    int w = std::max<int>(static_cast<int>(fbwindow().width() + 
-                                      m_step_size_x * fbwindow().winClient().width_inc), 
+
+    int w = std::max<int>(static_cast<int>(fbwindow().width() +
+                                      m_step_size_x * fbwindow().winClient().width_inc),
                      fbwindow().frame().titlebarHeight() * 2 + 10);
-    int h = std::max<int>(static_cast<int>(fbwindow().height() + 
-                                      m_step_size_y * fbwindow().winClient().height_inc), 
+    int h = std::max<int>(static_cast<int>(fbwindow().height() +
+                                      m_step_size_y * fbwindow().winClient().height_inc),
                      fbwindow().frame().titlebarHeight() + 10);
     fbwindow().resize(w, h);
 }
@@ -143,7 +143,7 @@ void MoveToCmd::real_execute() {
     int y = 0;
 
     const int head = fbwindow().screen().getHead(fbwindow().fbWindow());
-    
+
     if (m_refc & MoveToCmd::LOWER)
         y = fbwindow().screen().maxBottom(head) - fbwindow().height() - 2 * fbwindow().frame().window().borderWidth() - m_step_size_y;
     if (m_refc & MoveToCmd::UPPER)
@@ -157,7 +157,7 @@ void MoveToCmd::real_execute() {
         x = fbwindow().x();
     if (m_refc & MoveToCmd::IGNORE_Y)
         y = fbwindow().y();
-    
+
     fbwindow().move(x, y);
 }
 
@@ -174,3 +174,33 @@ FullscreenCmd::FullscreenCmd() { }
 void FullscreenCmd::real_execute() {
     fbwindow().setFullscreen(!fbwindow().isFullscreen());
 }
+
+SetAlphaCmd::SetAlphaCmd(int focused, bool relative,
+                         int unfocused, bool un_relative) :
+    m_focus(focused), m_unfocus(unfocused),
+    m_relative(relative), m_un_relative(un_relative) { }
+
+void SetAlphaCmd::real_execute() {
+    if (m_focus == 256 && m_unfocus == 256) {
+        // made up signal to return to default
+        fbwindow().setUseDefaultAlpha(true);
+        return;
+    }
+
+    int new_alpha;
+    if (m_relative) {
+        new_alpha = fbwindow().getFocusedAlpha() + m_focus;
+        if (new_alpha < 0) new_alpha = 0;
+        if (new_alpha > 255) new_alpha = 255;
+        fbwindow().setFocusedAlpha(new_alpha);
+    } else
+        fbwindow().setFocusedAlpha(m_focus);
+
+    if (m_un_relative) {
+        new_alpha = fbwindow().getUnfocusedAlpha() + m_unfocus;
+        if (new_alpha < 0) new_alpha = 0;
+        if (new_alpha > 255) new_alpha = 255;
+        fbwindow().setUnfocusedAlpha(new_alpha);
+    } else
+        fbwindow().setUnfocusedAlpha(m_unfocus);
+}
