@@ -19,7 +19,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: ToolFactory.cc 4199 2006-02-16 06:53:05Z mathias $
+// $Id: ToolFactory.cc 4846 2007-04-08 18:01:01Z markt $
 
 #include "ToolFactory.hh"
 
@@ -65,7 +65,8 @@ public:
                                 m_tbar.screen().getHeadWidth(head),
                                 m_tbar.screen().getHeadHeight(head));
         m_tbar.menu().move(m.first, m.second);
-        m_tbar.menu().show();        
+        m_tbar.menu().show();
+        m_tbar.menu().grabInputFocus();
     }
 private:
     Toolbar &m_tbar;
@@ -77,9 +78,9 @@ ToolFactory::ToolFactory(BScreen &screen):m_screen(screen),
     m_clock_theme(screen.screenNumber(), "toolbar.clock", "Toolbar.Clock"),
     m_button_theme(new ButtonTheme(screen.screenNumber(), "toolbar.button", "Toolbar.Button", 
                                    "toolbar.clock", "Toolbar.Clock")),
+    m_workspace_theme(new WorkspaceNameTheme(screen.screenNumber(), "toolbar.workspace", "Toolbar.Workspace")),
     m_systray_theme(new ButtonTheme(screen.screenNumber(), "toolbar.systray", "Toolbar.Systray",
                                     "toolbar.clock", "Toolbar.Systray")),
-    m_workspace_theme(new WorkspaceNameTheme(screen.screenNumber(), "toolbar.workspace", "Toolbar.Workspace")),
     m_iconbar_theme(screen.screenNumber(), "toolbar.iconbar", "Toolbar.Iconbar") {
 
 }
@@ -112,9 +113,9 @@ ToolbarItem *ToolFactory::create(const std::string &name, const FbTk::FbWindow &
             return 0;
 
 		// TODO maybe direction of arrows should depend on toolbar layout ?
-        ArrowButton::Type arrow_type = ArrowButton::LEFT;
+        FbTk::FbDrawable::TriangleType arrow_type = FbTk::FbDrawable::LEFT;
         if (name == "nextworkspace")
-            arrow_type = ArrowButton::RIGHT;
+            arrow_type = FbTk::FbDrawable::RIGHT;
 
         ArrowButton *win = new ArrowButton(arrow_type, parent,
                                            0, 0,
@@ -131,9 +132,9 @@ ToolbarItem *ToolFactory::create(const std::string &name, const FbTk::FbWindow &
         if (*cmd == 0) // we need a command
             return 0;
 
-        ArrowButton::Type arrow_type = ArrowButton::LEFT;
+        FbTk::FbDrawable::TriangleType arrow_type = FbTk::FbDrawable::LEFT;
         if (name == "nextwindow")
-            arrow_type = ArrowButton::RIGHT;
+            arrow_type = FbTk::FbDrawable::RIGHT;
                     
         ArrowButton *win = new ArrowButton(arrow_type, parent,
                                            0, 0,
@@ -159,7 +160,7 @@ void ToolFactory::updateThemes() {
 }
 
 
-int ToolFactory::maxFontHeight() const {
+int ToolFactory::maxFontHeight() {
     unsigned int max_height = 0;
     if (max_height < m_clock_theme.font().height())
         max_height = m_clock_theme.font().height();
